##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/cloud_credentials/operation/SharedGitGetAll)Get Shared Git Credentials
Get shared git credentials **Access policy** : Administrator only.
##### Authorizations:
(_ApiKeyAuth_ _jwt_)
### Responses
**201**
Success
**401**
Unauthorized
**500**
Server error
get/cloud/gitcredentials
https://api-docs.portainer.io/api/cloud/gitcredentials
